You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/08/08 14:22:43 UTC

[commons-io] branch master updated: Use the same names for arguments as the JDK, less confusing.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-io.git


The following commit(s) were added to refs/heads/master by this push:
     new 48f6d3f  Use the same names for arguments as the JDK, less confusing.
48f6d3f is described below

commit 48f6d3f4e0446eb7d749a945774b3c61c87aed78
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Thu Aug 8 10:22:38 2019 -0400

    Use the same names for arguments as the JDK, less confusing.
---
 src/main/java/org/apache/commons/io/output/ProxyWriter.java | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/main/java/org/apache/commons/io/output/ProxyWriter.java b/src/main/java/org/apache/commons/io/output/ProxyWriter.java
index 67c97e8..c234079 100644
--- a/src/main/java/org/apache/commons/io/output/ProxyWriter.java
+++ b/src/main/java/org/apache/commons/io/output/ProxyWriter.java
@@ -122,19 +122,19 @@ public class ProxyWriter extends FilterWriter {
 
     /**
      * Invokes the delegate's <code>write(char[])</code> method.
      * @param chr the characters to write
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void write(final char[] chr) throws IOException {
+    public void write(final char[] cbuf) throws IOException {
         try {
             int len = 0;
-            if (chr != null) {
-                len = chr.length;
+            if (cbuf != null) {
+                len = cbuf.length;
             }
 
             beforeWrite(len);
-            out.write(chr);
+            out.write(cbuf);
             afterWrite(len);
         } catch (final IOException e) {
             handleIOException(e);
@@ -122,19 +122,19 @@ public class ProxyWriter extends FilterWriter {
     /**
      * Invokes the delegate's <code>write(char[])</code> method.
-     * @param chr the characters to write
+     * @param cbuf the characters to write
      * @throws IOException if an I/O error occurs
      */